@@ -263,6 +263,10 @@ class Dumpulator(Architecture):
         else:
             thread = self._find_thread(thread_id)
 
+        self.thread_id = thread.ThreadId
+        self.process_id = self._minidump.misc_info.ProcessId
+        self.parent_process_id = (self.process_id // 4 + 69) * 4
+
         super().__init__(type(thread.ContextObject) is not minidump.WOW64_CONTEXT)
         self.addr_mask = 0xFFFFFFFFFFFFFFFF if self._x64 else 0xFFFFFFFF
 
@@ -430,7 +434,7 @@ class Dumpulator(Architecture):
 
     def _setup_pebteb(self, thread):
         self.teb = thread.Teb & 0xFFFFFFFFFFFFF000
-        is_wow64 = self.modules["ntdll.dll"].find_export("Wow64Transition") is not None
+        self.wow64 = self.modules["ntdll.dll"].find_export("Wow64Transition") is not None
 
         for i in range(0, len(self._minidump.threads.threads)):
             thread = self._minidump.threads.threads[i]
@@ -451,7 +455,7 @@ class Dumpulator(Architecture):
 
             teb_size = 2 * PAGE_SIZE
             self.memory.set_region_info(teb, f"TEB (thread {tid})", size=teb_size)
-            if is_wow64:
+            if self.wow64:
                 self.memory.set_region_info(teb - teb_size, f"WoW64 TEB (thread {tid})", size=teb_size)
 
         # https://en.wikipedia.org/wiki/Win32_Thread_Information_Block
@@ -501,7 +505,7 @@ class Dumpulator(Architecture):
             leap_second_data = self.read_ptr(self.peb + 0x470)
 
         self.memory.set_region_info(self.peb, "PEB", size=PAGE_SIZE)
-        if is_wow64:
+        if self.wow64:
             self.memory.set_region_info(self.peb - PAGE_SIZE, "WoW64 PEB", size=PAGE_SIZE)
 
         self.info(f"TEB: 0x{self.teb:x}, PEB: 0x{self.peb:x}")
@@ -1068,7 +1072,7 @@ rsp in KiUserExceptionDispatcher:
         self.regs.cip = FORCE_KILL_ADDR
         self.kill_me = exc
         if exc is not None:
-            raise exc
+            return exc
         else:
             self.kill_me = True
             self._uc.emu_stop()
@@ -1371,13 +1375,13 @@ def _hook_code(uc: Uc, address, size, dp: Dumpulator):
     line += "\n"
     dp.trace.write(line)
 
-def _unicode_string_to_string(dp: Dumpulator, arg: P(UNICODE_STRING)):
+def _unicode_string_to_string(dp: Dumpulator, arg: P[UNICODE_STRING]):
     try:
         return arg[0].read_str()
     except IndexError:
         return None
 
-def _object_attributes_to_string(dp: Dumpulator, arg: P(OBJECT_ATTRIBUTES)):
+def _object_attributes_to_string(dp: Dumpulator, arg: P[OBJECT_ATTRIBUTES]):
     try:
         return arg[0].ObjectName[0].read_str()
     except IndexError:
@@ -1399,7 +1403,7 @@ def _arg_to_string(dp: Dumpulator, arg):
         if hstr is not None:
             str += f" /* {hstr} */"
         return str
-    elif isinstance(arg, PVOID):
+    elif P.is_ptr(arg):
         str = hex(arg.ptr)
         tstr = None
         if arg.type is OBJECT_ATTRIBUTES:
@@ -1414,7 +1418,7 @@ def _arg_to_string(dp: Dumpulator, arg):
     raise NotImplemented()
 
 def _arg_type_string(arg):
-    if isinstance(arg, PVOID) and arg.type is not None:
+    if P.is_ptr(arg) and arg.type is not None:
         return arg.type.__name__ + "*"
     return type(arg).__name__
 
@@ -1491,13 +1495,13 @@ def _hook_syscall(uc: Uc, dp: Dumpulator):
                     sal_pretty = str(sal) + " "
 
                 argvalue = syscall_arg(i)
-                if issubclass(argtype, PVOID):
-                    argvalue = argtype(argvalue, dp)
+                if P.is_ptr(argtype):
+                    argvalue = argtype(dp, argvalue)
                 elif issubclass(argtype, Enum):
                     try:
                         argvalue = argtype(dp.args[i] & 0xFFFFFFFF)
                     except KeyError as x:
-                        raise Exception(f"Unknown enum value {dp.args[i]} for {type(argtype)}")
+                        raise Exception(f"Unknown enum value {dp.args[i]} for {type(argtype)}") from None
                 else:
                     argvalue = argtype(argvalue)
                 args.append(argvalue)
@@ -1513,7 +1517,7 @@ def _hook_syscall(uc: Uc, dp: Dumpulator):
                 if isinstance(status, ExceptionInfo):
                     print("context switch, stopping emulation")
                     dp.exception = status
-                    dp.raise_kill(UcError(UC_ERR_EXCEPTION))
+                    raise dp.raise_kill(UcError(UC_ERR_EXCEPTION)) from None
                 else:
                     dp.info(f"status = {status:x}")
                     dp.regs.cax = status
@@ -1526,17 +1530,14 @@ def _hook_syscall(uc: Uc, dp: Dumpulator):
             except UcError as err:
                 raise err
             except Exception as exc:
-                traceback.print_exc()
                 dp.error(f"Exception thrown during syscall implementation, stopping emulation!")
-                dp.raise_kill(exc)
+                raise dp.raise_kill(exc) from None
             finally:
                 dp.sequence_id += 1
         else:
-            dp.error(f"syscall index: {index:x} -> {name} not implemented!")
-            dp.raise_kill(NotImplementedError())
+            raise dp.raise_kill(NotImplementedError(f"syscall index: {index:x} -> {name} not implemented!")) from None
     else:
-        dp.error(f"syscall index {index:x} out of range")
-        dp.raise_kill(IndexError())
+        raise dp.raise_kill(IndexError(f"syscall index {index:x} out of range")) from None
 
 def _emulate_unsupported_instruction(dp: Dumpulator, instr: CsInsn):
     if instr.id == X86_INS_RDRAND:
