@@ -596,12 +596,13 @@ def SECTION_IMAGE_INFORMATION(arch: Architecture):
         ]
     return SECTION_IMAGE_INFORMATION()
 
-def P(t):
-    class P(PVOID):
-        def __init__(self, ptr, mem_read):
-            super().__init__(ptr, mem_read)
-            self.type = t
-    return P
+class PROCESS_BASIC_INFORMATION(Struct):
+    ExitStatus: ULONG
+    PebBaseAddress: PVOID
+    AffinityMask: KAFFINITY
+    BasePriority: KPRIORITY
+    UniqueProcessId: ULONG_PTR
+    InheritedFromUniqueProcessId: ULONG_PTR
 
 class KEY_VALUE_FULL_INFORMATION(ctypes.Structure):
     _fields_ = [
